==> zio-aws-ec2_2.12-5.17.145.1-sources.jar: zio/aws/ec2/model/OnDemandOptions.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class OnDemandOptions(
    allocationStrategy: Option[
      zio.aws.ec2.model.FleetOnDemandAllocationStrategy
    ] = None,
    capacityReservationOptions: Option[
      zio.aws.ec2.model.CapacityReservationOptions
    ] = None,
    singleInstanceType: Option[Boolean] = None,
    singleAvailabilityZone: Option[Boolean] = None,
    minTargetCapacity: Option[Integer] = None,
    maxTotalPrice: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.OnDemandOptions = {
    import OnDemandOptions.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.OnDemandOptions
      .builder()
      .optionallyWith(allocationStrategy.map(value => value.unwrap))(
        _.allocationStrategy
      )
      .optionallyWith(
        capacityReservationOptions.map(value => value.buildAwsValue())
      )(_.capacityReservationOptions)
      .optionallyWith(
        singleInstanceType.map(value => value: java.lang.Boolean)
      )(_.singleInstanceType)
      .optionallyWith(
        singleAvailabilityZone.map(value => value: java.lang.Boolean)
      )(_.singleAvailabilityZone)
      .optionallyWith(minTargetCapacity.map(value => value: java.lang.Integer))(
        _.minTargetCapacity
      )
      .optionallyWith(maxTotalPrice.map(value => value: java.lang.String))(
        _.maxTotalPrice
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.OnDemandOptions.ReadOnly =
    zio.aws.ec2.model.OnDemandOptions.wrap(buildAwsValue())
}
object OnDemandOptions {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.OnDemandOptions
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.OnDemandOptions =
      zio.aws.ec2.model.OnDemandOptions(
        allocationStrategy.map(value => value),
        capacityReservationOptions.map(value => value.asEditable),
        singleInstanceType.map(value => value),
        singleAvailabilityZone.map(value => value),
        minTargetCapacity.map(value => value),
        maxTotalPrice.map(value => value)
      )
    def allocationStrategy
        : Option[zio.aws.ec2.model.FleetOnDemandAllocationStrategy]
    def capacityReservationOptions
        : Option[zio.aws.ec2.model.CapacityReservationOptions.ReadOnly]
    def singleInstanceType: Option[Boolean]
    def singleAvailabilityZone: Option[Boolean]
    def minTargetCapacity: Option[Integer]
    def maxTotalPrice: Option[String]
    def getAllocationStrategy: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.FleetOnDemandAllocationStrategy
    ] = AwsError.unwrapOptionField("allocationStrategy", allocationStrategy)
    def getCapacityReservationOptions: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.CapacityReservationOptions.ReadOnly
    ] = AwsError.unwrapOptionField(
      "capacityReservationOptions",
      capacityReservationOptions
    )
    def getSingleInstanceType: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("singleInstanceType", singleInstanceType)
    def getSingleAvailabilityZone: ZIO[Any, AwsError, Boolean] = AwsError
      .unwrapOptionField("singleAvailabilityZone", singleAvailabilityZone)
    def getMinTargetCapacity: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("minTargetCapacity", minTargetCapacity)
    def getMaxTotalPrice: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("maxTotalPrice", maxTotalPrice)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.OnDemandOptions
  ) extends zio.aws.ec2.model.OnDemandOptions.ReadOnly {
    override val allocationStrategy
        : Option[zio.aws.ec2.model.FleetOnDemandAllocationStrategy] = scala
      .Option(impl.allocationStrategy())
      .map(value =>
        zio.aws.ec2.model.FleetOnDemandAllocationStrategy.wrap(value)
      )
    override val capacityReservationOptions
        : Option[zio.aws.ec2.model.CapacityReservationOptions.ReadOnly] = scala
      .Option(impl.capacityReservationOptions())
      .map(value => zio.aws.ec2.model.CapacityReservationOptions.wrap(value))
    override val singleInstanceType: Option[Boolean] =
      scala.Option(impl.singleInstanceType()).map(value => value: Boolean)
    override val singleAvailabilityZone: Option[Boolean] =
      scala.Option(impl.singleAvailabilityZone()).map(value => value: Boolean)
    override val minTargetCapacity: Option[Integer] =
      scala.Option(impl.minTargetCapacity()).map(value => value: Integer)
    override val maxTotalPrice: Option[String] =
      scala.Option(impl.maxTotalPrice()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.OnDemandOptions
  ): zio.aws.ec2.model.OnDemandOptions.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.104.11-sources.jar: zio/aws/ec2/model/OnDemandOptions.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class OnDemandOptions(
    allocationStrategy: Option[
      zio.aws.ec2.model.FleetOnDemandAllocationStrategy
    ] = None,
    capacityReservationOptions: Option[
      zio.aws.ec2.model.CapacityReservationOptions
    ] = None,
    singleInstanceType: Option[Boolean] = None,
    singleAvailabilityZone: Option[Boolean] = None,
    minTargetCapacity: Option[Integer] = None,
    maxTotalPrice: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.OnDemandOptions = {
    import OnDemandOptions.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.OnDemandOptions
      .builder()
      .optionallyWith(allocationStrategy.map(value => value.unwrap))(
        _.allocationStrategy
      )
      .optionallyWith(
        capacityReservationOptions.map(value => value.buildAwsValue())
      )(_.capacityReservationOptions)
      .optionallyWith(
        singleInstanceType.map(value => value: java.lang.Boolean)
      )(_.singleInstanceType)
      .optionallyWith(
        singleAvailabilityZone.map(value => value: java.lang.Boolean)
      )(_.singleAvailabilityZone)
      .optionallyWith(
        minTargetCapacity.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.minTargetCapacity)
      .optionallyWith(maxTotalPrice.map(value => value: java.lang.String))(
        _.maxTotalPrice
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.OnDemandOptions.ReadOnly =
    zio.aws.ec2.model.OnDemandOptions.wrap(buildAwsValue())
}
object OnDemandOptions {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.OnDemandOptions
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.OnDemandOptions =
      zio.aws.ec2.model.OnDemandOptions(
        allocationStrategy.map(value => value),
        capacityReservationOptions.map(value => value.asEditable),
        singleInstanceType.map(value => value),
        singleAvailabilityZone.map(value => value),
        minTargetCapacity.map(value => value),
        maxTotalPrice.map(value => value)
      )
    def allocationStrategy
        : Option[zio.aws.ec2.model.FleetOnDemandAllocationStrategy]
    def capacityReservationOptions
        : Option[zio.aws.ec2.model.CapacityReservationOptions.ReadOnly]
    def singleInstanceType: Option[Boolean]
    def singleAvailabilityZone: Option[Boolean]
    def minTargetCapacity: Option[Integer]
    def maxTotalPrice: Option[String]
    def getAllocationStrategy: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.FleetOnDemandAllocationStrategy
    ] = AwsError.unwrapOptionField("allocationStrategy", allocationStrategy)
    def getCapacityReservationOptions: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.CapacityReservationOptions.ReadOnly
    ] = AwsError.unwrapOptionField(
      "capacityReservationOptions",
      capacityReservationOptions
    )
    def getSingleInstanceType: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("singleInstanceType", singleInstanceType)
    def getSingleAvailabilityZone: ZIO[Any, AwsError, Boolean] = AwsError
      .unwrapOptionField("singleAvailabilityZone", singleAvailabilityZone)
    def getMinTargetCapacity: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("minTargetCapacity", minTargetCapacity)
    def getMaxTotalPrice: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("maxTotalPrice", maxTotalPrice)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.OnDemandOptions
  ) extends zio.aws.ec2.model.OnDemandOptions.ReadOnly {
    override val allocationStrategy
        : Option[zio.aws.ec2.model.FleetOnDemandAllocationStrategy] = scala
      .Option(impl.allocationStrategy())
      .map(value =>
        zio.aws.ec2.model.FleetOnDemandAllocationStrategy.wrap(value)
      )
    override val capacityReservationOptions
        : Option[zio.aws.ec2.model.CapacityReservationOptions.ReadOnly] = scala
      .Option(impl.capacityReservationOptions())
      .map(value => zio.aws.ec2.model.CapacityReservationOptions.wrap(value))
    override val singleInstanceType: Option[Boolean] =
      scala.Option(impl.singleInstanceType()).map(value => value: Boolean)
    override val singleAvailabilityZone: Option[Boolean] =
      scala.Option(impl.singleAvailabilityZone()).map(value => value: Boolean)
    override val minTargetCapacity: Option[Integer] = scala
      .Option(impl.minTargetCapacity())
      .map(value => zio.aws.ec2.model.primitives.Integer(value))
    override val maxTotalPrice: Option[String] =
      scala.Option(impl.maxTotalPrice()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.OnDemandOptions
  ): zio.aws.ec2.model.OnDemandOptions.ReadOnly = new Wrapper(impl)
}
